/*
 Copyright (c) 1995-2024  by Arkkra Enterprises.
 All rights reserved.

 Redistribution and use in source and binary forms,
 with or without modification, are permitted provided that
 the following conditions are met:

 1. Redistributions of source code must retain
 the above copyright notice, this list of conditions
 and the following DISCLAIMER.

 2. Redistributions in binary form must reproduce the above
 copyright notice, this list of conditions and
 the following DISCLAIMER in the documentation and/or
 other materials provided with the distribution.

 3. Any additions, deletions, or changes to the original files
 must be clearly indicated in accompanying documentation,
 including the reasons for the changes,
 and the names of those who made the modifications.

	DISCLAIMER

 THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS
 OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 THE IMPLIED WARRANTIES OF MERCHANTABILITY
 AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY DIRECT,
 INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
 OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO
 PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE)
 ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef _SSVUSED_H
#define _SSVUSED_H

/*
 * This file contains the array subscript definitions for the used[] array
 * of an SSV struct. An SSV contains parameters associated with a
 * Score, Staff, or Voice.  The used[] array is a set of flags which say
 * whether a given parameter is actually populated in the SSV instance.
 * In the "score" SSV, all used flags are always set true.  In SSVs for
 * a staff or voice, a "used" flag is only set to true if the user
 * specified a value for the parameter in that staff or voice context.
 *
 * The actual values are machine-generated so they get automatically
 * renumbered if parameters are added or deleted or rearranged.
 *
 * We try to put things that are logically similar close together in
 * this list, but they could be in any order, other than that NUMFLDS
 * _must_ be last.
 */

#define	SCALE_FACTOR		(0)
#define	MUSICSCALE		(1)
#define	UNITS			(2)
#define	PAGEHEIGHT		(3)
#define	PAGEWIDTH		(4)
#define	PANELSPERPAGE		(5)
#define	MAXSCORES		(6)
#define	MAXMEASURES		(7)
#define	SLASHESBETWEEN		(8)
#define	TOPMARGIN		(9)
#define	BOTMARGIN		(10)
#define	LEFTMARGIN		(11)
#define	RIGHTMARGIN		(12)
#define	FLIPMARGINS		(13)
#define	INDENTRESTART		(14)
#define	RESTCOMBINE		(15)
#define	FIRSTPAGE		(16)
#define	NUMSTAFF		(17)
#define	MINSCSEP		(18)
#define	MAXSCSEP		(19)
#define	MINSCPAD		(20)
#define	MAXSCPAD		(21)
#define	BRACELIST		(22)
#define	BRACKLIST		(23)
#define	BARSTLIST		(24)
#define	SUBBARSTYLE		(25)
#define	TIME			(26)
#define	DIVISION		(27)
#define	ENDINGSTYLE		(28)
#define	ALIGNLABELS		(29)
#define	GRIDSATEND		(30)
#define	MEASNUM			(31)
#define	MEASNUMFAMILY		(32)
#define	MEASNUMFONT		(33)
#define	MEASNUMSIZE		(34)
#define	MEASNUMSTYLE		(35)
#define	PILESCALE		(36)
#define	BRACKETREPEATS		(37)
#define	PACKFACT		(38)
#define	PACKEXP			(39)
#define	LEFTSPACE		(40)
#define	WARN			(41)
#define	PRINTKEYMAP		(42)
#define	A4FREQ			(43)
#define	TUNING			(44)
#define	ACCTABLE		(45)
#define	STAFFSCALE		(46)
#define	VISIBLE			(47)
#define	STAFFLINES		(48)
#define	GRIDSWHEREUSED		(49)
#define	GRIDSCALE		(50)
#define	GRIDFRET		(51)
#define	MINGRIDHEIGHT		(52)
#define	NUMBERMRPT		(53)
#define	NUMBERMULTRPT		(54)
#define	PRINTMULTNUM		(55)
#define	RESTSYMMULT		(56)
#define	VSCHEME			(57)
#define	VCOMBINE		(58)
#define	PRINTEDTIME		(59)
#define	SHARPS			(60)
#define	CANCELKEY		(61)
#define	TRANSPOSITION		(62)
#define	ADDTRANSPOSITION	(63)
#define	USEACCS			(64)
#define	CARRYACCS		(65)
#define	CLEF			(66)
#define	REHSTYLE		(67)
#define	REPEATDOTS		(68)
#define	FONTFAMILY		(69)
#define	FONT			(70)
#define	SIZE			(71)
#define	REHFAMILY		(72)
#define	REHFONT			(73)
#define	REHSIZE			(74)
#define	LYRICSFAMILY		(75)
#define	LYRICSFONT		(76)
#define	LYRICSSIZE		(77)
#define	LYRICSALIGN		(78)
#define	SYLPOSITION		(79)
#define	MINALIGNSCALE		(80)
#define	MINSTSEP		(81)
#define	STAFFPAD		(82)
#define	ABOVEORDER		(83)
#define	BELOWORDER		(84)
#define	BETWEENORDER		(85)
#define	PEDSTYLE		(86)
#define	ALIGNPED		(87)
#define	CHORDDIST		(88)
#define	DIST			(89)
#define	DYNDIST			(90)
#define	LYRICSDIST		(91)
#define	CHORDTRANSLATION	(92)
#define	LABEL			(93)
#define	LABEL2			(94)
#define	LABELKEYMAP		(95)
#define	ENDINGKEYMAP		(96)
#define	REHEARSALKEYMAP		(97)
#define	DEFAULTKEYMAP		(98)
#define	WITHKEYMAP		(99)
#define	TEXTKEYMAP		(100)
#define	LYRICSKEYMAP		(101)
#define	BEAMSTLIST		(102)
#define	BEAMSLOPE		(103)
#define	TUPLETSLOPE		(104)
#define	PAD			(105)
#define	STEMLEN			(106)
#define	BEAMSHORT		(107)
#define	MAXPROSHORT		(108)
#define	BEGPROSHORT		(109)
#define	ENDPROSHORT		(110)
#define	MIDLINESTEMFLOAT	(111)
#define	DEFOCT			(112)
#define	NOTEINPUTDIR		(113)
#define	TIMEUNIT		(114)
#define	SWINGUNIT		(115)
#define	WITHFAMILY		(116)
#define	WITHFONT		(117)
#define	WITHSIZE		(118)
#define	NOTELEFTFAMILY		(119)
#define	NOTELEFTFONT		(120)
#define	NOTELEFTSIZE		(121)
#define	ALIGNRESTS		(122)
#define	RELEASE			(123)
#define	ONTHELINE		(124)
#define	TABWHITEBOX		(125)
#define	NOTEHEADS		(126)
#define	SHAPES			(127)
#define	EMPTYMEAS		(128)
#define	EXTENDLYRICS		(129)
#define	CUE			(130)
#define	DEFAULTPHRASESIDE	(131)
#define	NUMFLDS			(132)

#endif
